@@ -30,6 +30,12 @@ rating_policies = [
         description='Get specified module.',
         operations=[{'path': '/v2/rating/modules/{module_id}',
                      'method': 'GET'}]),
+    policy.DocumentedRuleDefault(
+        name='v2_rating:update_module',
+        check_str=base.ROLE_ADMIN,
+        description='Change the state and priority of a module.',
+        operations=[{'path': '/v2/rating/modules/{module_id}',
+                     'method': 'PUT'}])
 ]
 
 
