@@ -29,13 +29,11 @@ class HashMapBase(models.ModelBase):
                       'mysql_engine': "InnoDB"}
     fk_to_resolve = {}
 
-    def save(self, session=None):
+    def save(self):
         from cloudkitty import db
 
-        if session is None:
-            session = db.get_session()
-
-        super(HashMapBase, self).save(session=session)
+        with db.session_for_write() as session:
+            super(HashMapBase, self).save(session=session)
 
     def as_dict(self):
         d = {}
