@@ -86,9 +86,6 @@ class ElasticsearchStorage(v2_storage.BaseStorage):
     def __init__(self, *args, **kwargs):
         super(ElasticsearchStorage, self).__init__(*args, **kwargs)
 
-        LOG.warning('The Elasticsearch storage driver is experimental. '
-                    'DO NOT USE IT IN PRODUCTION.')
-
         verify = not CONF.storage_elasticsearch.insecure
         if verify and CONF.storage_elasticsearch.cafile:
             verify = CONF.storage_elasticsearch.cafile
@@ -194,6 +191,7 @@ class ElasticsearchStorage(v2_storage.BaseStorage):
         begin, end = self._local_to_utc(begin or tzutils.get_month_start(),
                                         end or tzutils.get_next_month())
 
+        groupby = self.parse_groupby_syntax_to_groupby_elements(groupby)
         total, docs = self._conn.total(begin, end, metric_types, filters,
                                        groupby, custom_fields=custom_fields,
                                        offset=offset, limit=limit,
