@@ -15,15 +15,15 @@
 #
 import copy
 import datetime
+from unittest import mock
 
-import mock
 import testscenarios
 
 from cloudkitty import storage
 from cloudkitty import tests
 from cloudkitty.tests import samples
 from cloudkitty.tests import utils as test_utils
-from cloudkitty import tzutils
+from cloudkitty.utils import tz as tzutils
 
 
 class StorageTest(tests.TestCase):
