@@ -116,7 +116,7 @@ function _cloudkitty_config_apache_wsgi {
         s|%APACHE_NAME%|$APACHE_NAME|g;
         s|%WSGIAPP%|$CLOUDKITTY_WSGI_DIR/app.wsgi|g;
         s|%USER%|$STACK_USER|g;
-        s|%VIRTUALENV%|$venv_path|g
+        s|%VIRTUALENV%|$DEVSTACK_VENV|g
     " -i $cloudkitty_apache_conf
 }
 
@@ -165,7 +165,7 @@ function configure_cloudkitty {
         iniset $CLOUDKITTY_CONF fetcher_keystone keystone_version 3
     fi
 
-    if [ "$CLOUDKITTY_STORAGE_BACKEND" == "influxdb" ]; then
+    if [ "$CLOUDKITTY_STORAGE_BACKEND" == "influxdb" ] && [ "$CLOUDKITTY_INFLUX_VERSION" == 1 ]; then
         iniset $CLOUDKITTY_CONF storage_${CLOUDKITTY_STORAGE_BACKEND} user ${CLOUDKITTY_INFLUXDB_USER}
         iniset $CLOUDKITTY_CONF storage_${CLOUDKITTY_STORAGE_BACKEND} password ${CLOUDKITTY_INFLUXDB_PASSWORD}
         iniset $CLOUDKITTY_CONF storage_${CLOUDKITTY_STORAGE_BACKEND} database ${CLOUDKITTY_INFLUXDB_DATABASE}
@@ -173,11 +173,24 @@ function configure_cloudkitty {
         iniset $CLOUDKITTY_CONF storage_${CLOUDKITTY_STORAGE_BACKEND} port ${CLOUDKITTY_INFLUXDB_PORT}
     fi
 
+    if [ "$CLOUDKITTY_STORAGE_BACKEND" == "influxdb" ] && [ "$CLOUDKITTY_INFLUX_VERSION" == 2 ]; then
+        iniset $CLOUDKITTY_CONF storage_${CLOUDKITTY_STORAGE_BACKEND} host ${CLOUDKITTY_INFLUXDB_HOST}
+        iniset $CLOUDKITTY_CONF storage_${CLOUDKITTY_STORAGE_BACKEND} port ${CLOUDKITTY_INFLUXDB_PORT}
+        iniset $CLOUDKITTY_CONF storage_${CLOUDKITTY_STORAGE_BACKEND} url "http://${CLOUDKITTY_INFLUXDB_HOST}:${CLOUDKITTY_INFLUXDB_PORT}"
+        iniset $CLOUDKITTY_CONF storage_${CLOUDKITTY_STORAGE_BACKEND} token ${CLOUDKITTY_INFLUXDB_PASSWORD}
+        iniset $CLOUDKITTY_CONF storage_${CLOUDKITTY_STORAGE_BACKEND} version 2
+    fi
+
     if [ "$CLOUDKITTY_STORAGE_BACKEND" == "elasticsearch" ]; then
         iniset $CLOUDKITTY_CONF storage_${CLOUDKITTY_STORAGE_BACKEND} host ${CLOUDKITTY_ELASTICSEARCH_HOST}
         iniset $CLOUDKITTY_CONF storage_${CLOUDKITTY_STORAGE_BACKEND} index_name ${CLOUDKITTY_ELASTICSEARCH_INDEX}
     fi
 
+    if [ "$CLOUDKITTY_STORAGE_BACKEND" == "opensearch" ]; then
+        iniset $CLOUDKITTY_CONF storage_${CLOUDKITTY_STORAGE_BACKEND} host ${CLOUDKITTY_OPENSEARCH_HOST}
+        iniset $CLOUDKITTY_CONF storage_${CLOUDKITTY_STORAGE_BACKEND} index_name ${CLOUDKITTY_OPENSEARCH_INDEX}
+    fi
+
     # collect
     iniset $CLOUDKITTY_CONF collect collector $CLOUDKITTY_COLLECTOR
     iniset $CLOUDKITTY_CONF "collector_${CLOUDKITTY_COLLECTOR}" auth_section authinfos
@@ -237,9 +250,13 @@ function create_cloudkitty_data_dir {
 }
 
 function create_influxdb_database {
-    if [ "$CLOUDKITTY_STORAGE_BACKEND" == "influxdb" ]; then
+    if [ "$CLOUDKITTY_STORAGE_BACKEND" == "influxdb" ] && [ "$CLOUDKITTY_INFLUX_VERSION" == 1 ]; then
         influx -execute "CREATE DATABASE ${CLOUDKITTY_INFLUXDB_DATABASE}"
     fi
+    if [ "$CLOUDKITTY_STORAGE_BACKEND" == "influxdb" ] && [ "$CLOUDKITTY_INFLUX_VERSION" == 2 ]; then
+        influx setup --username ${CLOUDKITTY_INFLUXDB_USER} --password ${CLOUDKITTY_INFLUXDB_PASSWORD} --token ${CLOUDKITTY_INFLUXDB_PASSWORD} --org openstack --bucket cloudkitty --force
+    fi
+
 }
 
 function create_elasticsearch_index {
@@ -248,6 +265,12 @@ function create_elasticsearch_index {
     fi
 }
 
+function create_opensearch_index {
+    if [ "$CLOUDKITTY_STORAGE_BACKEND" == "opensearch" ]; then
+        curl -XPUT "${CLOUDKITTY_OPENSEARCH_HOST}/${CLOUDKITTY_OPENSEARCH_INDEX}"
+    fi
+}
+
 # init_cloudkitty() - Initialize CloudKitty database
 function init_cloudkitty {
     # Delete existing cache
@@ -265,9 +288,10 @@ function init_cloudkitty {
 
     create_influxdb_database
     create_elasticsearch_index
+    create_opensearch_index
 
     # Migrate cloudkitty database
-    $CLOUDKITTY_BIN_DIR/cloudkitty-dbsync upgrade
+    upgrade_cloudkitty_database
 
     # Init the storage backend
     if [ $CLOUDKITTY_STORAGE_BACKEND == 'hybrid' ]; then
@@ -284,11 +308,27 @@ function install_influx_ubuntu {
     sudo dpkg -i --skip-same-version ${influxdb_file}
 }
 
+function install_influx_v2_ubuntu {
+    local influxdb_file=$(get_extra_file https://dl.influxdata.com/influxdb/releases/influxdb2_2.7.5-1_amd64.deb)
+    sudo dpkg -i --skip-same-version ${influxdb_file}
+    local influxcli_file=$(get_extra_file https://dl.influxdata.com/influxdb/releases/influxdb2-client-2.7.3-linux-amd64.tar.gz)
+    tar xvzf ${influxcli_file}
+    sudo cp ./influx /usr/local/bin/
+}
+
 function install_influx_fedora {
     local influxdb_file=$(get_extra_file https://dl.influxdata.com/influxdb/releases/influxdb-1.6.3.x86_64.rpm)
     sudo yum localinstall -y ${influxdb_file}
 }
 
+function install_influx_v2_fedora {
+    local influxdb_file=$(get_extra_file https://dl.influxdata.com/influxdb/releases/influxdb2-2.7.5-1.x86_64.rpm)
+    sudo yum localinstall -y ${influxdb_file}
+    local influxcli_file=$(get_extra_file https://dl.influxdata.com/influxdb/releases/influxdb2-client-2.7.3-linux-amd64.tar.gz)
+    tar xvzf ${influxcli_file}
+    sudo cp ./influx /usr/local/bin/
+}
+
 function install_influx {
     if is_ubuntu; then
         install_influx_ubuntu
@@ -301,16 +341,27 @@ function install_influx {
     sudo systemctl start influxdb || sudo systemctl restart influxdb
 }
 
+
+function install_influx_v2 {
+    if is_ubuntu; then
+        install_influx_v2_ubuntu
+    elif is_fedora; then
+        install_influx_v2_fedora
+    else
+        die $LINENO "Distribution must be Debian or Fedora-based"
+    fi
+    sudo cp -f "${CLOUDKITTY_DIR}"/devstack/files/influxdb.conf /etc/influxdb/influxdb.conf
+    sudo systemctl start influxdb || sudo systemctl restart influxdb
+}
+
 function install_elasticsearch_ubuntu {
-    sudo apt install -qy openjdk-8-jre
-    local elasticsearch_file=$(get_extra_file https://artifacts.elastic.co/downloads/elasticsearch/elasticsearch-6.8.3.deb)
-    sudo dpkg -i --skip-same-version ${elasticsearch_file}
+    local opensearch_file=$(get_extra_file https://artifacts.opensearch.org/releases/bundle/opensearch/1.3.9/opensearch-1.3.9-linux-x64.deb)
+    sudo dpkg -i --skip-same-version ${opensearch_file}
 }
 
 function install_elasticsearch_fedora {
-    sudo yum install -y java-1.8.0-openjdk
-    local elasticsearch_file=$(get_extra_file https://artifacts.elastic.co/downloads/elasticsearch/elasticsearch-6.8.3.rpm)
-    sudo yum localinstall -y ${elasticsearch_file}
+    local opensearch_file=$(get_extra_file https://artifacts.opensearch.org/releases/bundle/opensearch/1.3.9/opensearch-1.3.9-linux-x64.rpm)
+    sudo yum localinstall -y ${opensearch_file}
 }
 
 function install_elasticsearch {
@@ -321,18 +372,50 @@ function install_elasticsearch {
     else
         die $LINENO "Distribution must be Debian or Fedora-based"
     fi
-    sudo systemctl start elasticsearch || sudo systemctl restart elasticsearch
+    if ! sudo grep plugins.security.disabled /etc/opensearch/opensearch.yml >/dev/null; then
+        echo "plugins.security.disabled: true" | sudo tee -a /etc/opensearch/opensearch.yml >/dev/null
+    fi
+    sudo systemctl enable opensearch
+    sudo systemctl start opensearch || sudo systemctl restart opensearch
+}
+
+function install_opensearch_ubuntu {
+    local opensearch_file=$(get_extra_file https://artifacts.opensearch.org/releases/bundle/opensearch/2.11.0/opensearch-2.11.0-linux-x64.deb)
+    sudo dpkg -i --skip-same-version ${opensearch_file}
+}
+
+function install_opensearch_fedora {
+    local opensearch_file=$(get_extra_file https://artifacts.opensearch.org/releases/bundle/opensearch/2.11.0/opensearch-2.11.0-linux-x64.rpm)
+    sudo yum localinstall -y ${opensearch_file}
+}
+
+function install_opensearch {
+    if is_ubuntu; then
+        install_opensearch_ubuntu
+    elif is_fedora; then
+        install_opensearch_fedora
+    else
+        die $LINENO "Distribution must be Debian or Fedora-based"
+    fi
+    if ! sudo grep plugins.security.disabled /etc/opensearch/opensearch.yml >/dev/null; then
+        echo "plugins.security.disabled: true" | sudo tee -a /etc/opensearch/opensearch.yml >/dev/null
+    fi
+    sudo systemctl enable opensearch
+    sudo systemctl start opensearch || sudo systemctl restart opensearch
 }
 
 # install_cloudkitty() - Collect source and prepare
 function install_cloudkitty {
     git_clone $CLOUDKITTY_REPO $CLOUDKITTY_DIR $CLOUDKITTY_BRANCH
     setup_develop $CLOUDKITTY_DIR
-
-    if [ $CLOUDKITTY_STORAGE_BACKEND == 'influxdb' ]; then
+    if [ $CLOUDKITTY_STORAGE_BACKEND == 'influxdb' ] && [ "$CLOUDKITTY_INFLUX_VERSION" == 1 ]; then
         install_influx
+    elif [ $CLOUDKITTY_STORAGE_BACKEND == 'influxdb' ] && [ "$CLOUDKITTY_INFLUX_VERSION" == 2 ]; then
+        install_influx_v2
     elif [ $CLOUDKITTY_STORAGE_BACKEND == 'elasticsearch' ]; then
         install_elasticsearch
+    elif [ $CLOUDKITTY_STORAGE_BACKEND == 'opensearch' ]; then
+        install_opensearch
     fi
 }
 
@@ -340,7 +423,7 @@ function install_cloudkitty {
 function start_cloudkitty {
     run_process ck-proc "$CLOUDKITTY_BIN_DIR/cloudkitty-processor --config-file=$CLOUDKITTY_CONF"
     if [[ "$CLOUDKITTY_USE_MOD_WSGI" == "False" ]]; then
-        run_process ck-api "$CLOUDKITTY_BIN_DIR/cloudkitty-api --config-file=$CLOUDKITTY_CONF"
+        run_process ck-api "$CLOUDKITTY_BIN_DIR/cloudkitty-api --host $CLOUDKITTY_SERVICE_HOST --port $CLOUDKITTY_SERVICE_PORT"
     elif is_service_enabled ck-api; then
         enable_apache_site cloudkitty
         echo_summary "Waiting 15s for cloudkitty-processor to authenticate against keystone before apache is restarted."
@@ -402,6 +485,11 @@ function update_horizon_static {
     restart_apache_server
 }
 
+# Upgrade cloudkitty database
+function upgrade_cloudkitty_database {
+    $CLOUDKITTY_BIN_DIR/cloudkitty-dbsync upgrade
+}
+
 # configure_cloudkitty_dashboard() - Set config files, create data dirs, etc
 function configure_cloudkitty_dashboard {
     sudo ln -s  $CLOUDKITTY_ENABLED_DIR/_[0-9]*.py \
